#
# spec file for package chezmoi
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           chezmoi
Version:        2.59.0
Release:        1.1
Summary:        A multi-host manager for dotfiles
License:        MIT
Group:          Development/Tools/Version Control
URL:            https://chezmoi.io
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
Recommends:     git
BuildRequires:  golang(API) >= 1.22

%description
chezmoi is a manager for personal preference configs and state files
("dotfiles") that programs such as editors might create. chezmoi
sources dotfiles from a GitHub repository and installs them onto new,
empty machines.

%package bash-completion
Summary:        Bash completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash command line completion support for %{name}.

%package fish-completion
Summary:        Fish completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description fish-completion
Fish command line completion support for %{name}.

%package zsh-completion
Summary:        Zsh completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
Zsh command line completion support for %{name}.

%prep
%autosetup -a 1

%build
go build \
        -mod=vendor \
        -buildmode=pie \
        -tags noupgrade \
        -ldflags "-X main.version=%version
                  -X main.builtBy=build.opensuse.org"

%check
# Skip TestGoToolDistList test, which builds and installs from scratch from the Git repo
go test \
        -mod=vendor \
        -buildmode=pie \
        -skip TestGoToolDistList \
        ./...

%install
install -D -m 0755 %{name} "%{buildroot}/%{_bindir}/%{name}"
install -D -m 0644 "completions/%{name}-completion.bash" "%{buildroot}/%{_datadir}/bash-completion/completions/%{name}"
install -D -m 0644 "completions/%{name}.fish" "%{buildroot}/%{_datadir}/fish/vendor_completions.d/%{name}.fish"
install -D -m 0644 "completions/%{name}.zsh" "%{buildroot}/%{_datadir}/zsh/site-functions/_%{name}"

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}

%files bash-completion
%{_datadir}/bash-completion/completions/%{name}

%files fish-completion
%dir %{_datadir}/fish
%dir %{_datadir}/fish/vendor_completions.d
%{_datadir}/fish/vendor_completions.d/%{name}.fish

%files zsh-completion
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_%{name}

%changelog
* Tue Jan 28 2025 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.59.0:
  - Features
  * feat: Add git-auto-commit and git-auto-push hooks
  * feat: Add warnf template function
  * feat: Show original URL in HTTP progress bars
  * feat: Support filenames containing # in ignore and remove files
  - Fixes
  * fix: Fix persistent state mode for commands that execute templates
  * fix: Warn, don't error, when generating git commit messages for unknown states
  - Documentation updates
  * docs: Update pruneEmptyDicts example
* Mon Jan 13 2025 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.58.0:
  - Features
  * feat: Add --git-lfs option to init command
  * feat: Add builtin mode for gopass
  * feat: Improve placeholders in password prompts
  * feat: Show all contributors in README.md
  - Fixes
  * fix: Fix doctor command when --config is specified
  * fix: Correct nested groups for keepassxc builtin mode
  * fix: Suppress gitleaks logspam
  - Documentation updates
  * docs: Tidy up formatting as suggested by markdownlint
- Reorder services to avoid go_modules version mismatch warning
* Tue Jan  7 2025 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.57.0:
  - Features
  * feat: Add chezmoi:template:format-indent template directive
  * feat: Implement builtin mode for keepassxc
  * feat: Add script hooks that use configured interpreters
* Wed Dec 18 2024 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.56.0:
  - Features
  * feat: Use textconv with external diff commands
  * feat: Add interactive config variable
  * feat: Add initial policy on LLM-generated contributions
  * feat: Warn about future removal of insecure hashes
  * feat: Add .chezmoi.destDir template variable
  - Fixes
  * fix: Replace Expand-Archive with System.IO.Compression.ZipFile
  * fix: More reliable arch detection in install.ps1
  * fix: YAML parsing error by escaping | in title
  - Documentation updates
  * docs: Describe how to use tools installed with Flatpak
* Mon Dec  2 2024 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.55.0:
  - Features
  * feat: Add multiple URL support for externals
  * feat: Warn if the user is using the Helix editor with chezmoi edit
  * feat: Support file:// URLs in externals
  - Fixes
  * fix: Fix error when choice variables are set in flags and config file
* Mon Nov 11 2024 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.54.0:
  - Features
  * feat: Add --path-style=all option to managed command
  * feat: Inform user when to use get.chezmoi.io/lb
  - Fixes
  * fix: Perform post-run actions on error
  - Documentation updates
  * docs: Add github.com/andre-kotake/nvim-chezmoi to related software
- Add chezmoi test suite to %%check section
* Tue Oct 29 2024 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.53.1:
  - Fixes
  * fix: Fix panic in commands that do not use persistent state
  - Documentation updates
  * docs: Add note that .chezmoiexternal files can be ignored
* Tue Oct 29 2024 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.53.0:
  - Features
  * feat: Extend squote template func to handle more types
  * feat: Extend quote and quoteList template funcs to handle more types
  * feat: Add common --parent-dirs/-P flag
  - Fixes
  * fix: Persist results of calls to GitHub API
  * fix: Fix completion for 'archive --format'
  * fix: Fix includeTemplate template func search path in init
  * fix: Accept only supported values to 'unmanaged --path-style'
  * fix: Fix incorrect config template change warnings
  * fix: Fix panic when --keep-going is set
  * fix: Fix panic when running chattr on externals
  * fix: Use builtin age when encryption is unset
  - Documentation updates
  * docs: Replace common flags descriptions with snippets
  * docs: Fill reference title page
  * docs: Update "how scripts work" section
  * docs: Update shell completions section
  * docs: Improvements for command flags description
  * docs: Automatically check that all flags are documented
  * docs: Split "Special file and directories"
  * docs: Split docs for commands into sections
  * docs: Split docs into sections for age, secret and state
  * docs: Improve description for command arguments
  * docs: Add notes where to place 'encryption' setting
* Mon Sep 30 2024 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.52.3:
  - Features
  * feat: Set GOMAXPROCS based on available resources
  - Documentation updates
  * docs: Improve developer documentation
  * docs: Use uv for managing Python and dependencies
  * docs: Add note on reporting viruses or trojans on Windows
  * docs: Add sequence diagram for chezmoi init
  * docs: Add daily usage entry on editing files
* Tue Sep 10 2024 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.52.2:
  - Features
  * feat: Support YubiKeys in KeePassXC open mode
  - Documentation updates
  * docs: Add FAQ entry on using delta as the diff tool
  * docs: Add FAQ entry on running scripts periodically
  * docs: Add FAQ entry on running a script when a git-repo external changes
  * docs: Add FAQ entry on literal {{ and }} in templates
  * docs: Add warning on using externals for large files or archives
  * docs: Add how to use VSCode as the diff and merge tool
* Tue Aug 27 2024 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.52.1:
  - Fixes
    cba7e40 fix: Set User-Agent header to chezmoi.io/version on all HTTP requests
- Bump go version to 1.22 as per upstream go.mod
* Thu Aug  8 2024 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.52.0:
  - Features
  * feat: Add gitHubRelease and gitHubReleaseAssetURL template functions
  - Fixes
  * fix: Don't modify ciphertext in edit command if plaintext did not change
* Tue Jul 16 2024 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.51.0:
  - Features
  * feat: Add 1Password SDK template funcs
  * feat: Add decompression of file externals
  - Fixes
  * fix: keep initFuncs when using 'includeTemplate' in config
  * fix: Use scriptTempDir for modify_ scripts
* Tue Jul  9 2024 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.50.0:
  - Features
  * feat: Add tempDir configuration variable
  * feat: Allow private_ and readonly_ attrs to be set for externals
  * feat: Add --no-network flag to doctor command
  * feat: Embed fallback X.509 trusted roots
  - Fixes
  * fix: Prevent chezmoi add from adding chezmoi's own executable
* Mon Jun 24 2024 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.49.1:
  - Fixes
  * fix: Accept line-endings template directive as well as line-ending
* Tue Jun 11 2024 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.49.0:
  - Features
  * feat: Add stub for removed remove command
  * feat: Rename remove command to destroy
  - Fixes
  * fix: Fix panic when parsing some commands
  - Documentation updates
  * docs: Update comparison-table.md
* Mon Jun  3 2024 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.48.2:
  - Fixes
  * fix: Don't panic on unexpected bubbletea messages
  * fix: Respect umask when creating files
* Tue Apr 30 2024 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.48.0:
  - Features
  * feat: Add --tree flag to unmanaged command
  * feat: Add --tree flag to managed command
  * feat: Add --tree flag to ignored command
  * feat: Include name of target in error message
  - Fixes
  * fix: Apply .chezmoiignore to dirs in external archives
  * fix: Remove unmanaged files from exact_ directories containing external files
  * fix: Better detect username on Android/Termux systems
  - Documentation updates
  * docs: Document --tree flag
* Tue Apr 16 2024 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.47.4:
  - Fixes
  * fix: Fix potential panic when textconv interpreter is empty
  * fix: Fix panic on empty external
* Wed Apr  3 2024 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.47.3:
  - Fixes
  * fix: Don't traverse into ignored directories when adding files
  * fix: Skip adding entries in external dirs instead of erroring
  * fix: Fix panic when adding children in exact_ dirs
  * fix: Increase range of types accepted by promptChoice template function
* Mon Mar 18 2024 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.47.2:
  - Fixes
  * fix: pass the --needed flag to pacman
  * fix: Remove fig support
  * fix: Explicitly tell user when then should use a config file template
  * fix: Handle copies in automatic commit messages
  * fix: Add missing newlines in error messages
  - Documentation updates
  * docs: Fix incomplete sentence in usage docs
* Mon Mar  4 2024 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.47.1:
  - Fixes
  * fix: Fix panic in unmanaged on some dir permission errors
  * fix: Make splitList return []any
  * fix: Set CHEZMOI_ environment variables for plugins
  * fix: Ensure that all .chezmoi.config template variables have simple types
  * fix: a grammar mistake
  - Documentation updates
  * docs: Refactor developer guide
* Mon Feb 26 2024 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.47.0:
  - Features
  * feat: 1Password Secrets Automation Support
  - Fixes
  * fix: Ensure default mode is set
  * fix: Fix marshaling of severities
  * fix: Fix marshaling of autobools
  * fix: Fix marshaling of absolute paths
  * fix: Fix --keep-going flag for unmanaged command
  * fix: Don't leak internal default sentinel values in template data
  * fix: Fix panic when merging unmanaged file
  * fix: Don't attempt to add entries in external_ directories
  * fix: Use uname -o to detect Android in install script
  * fix: Move documentation of --output flag to correct section
  * fix: Prioritize $HOME when Cygwin or msys2 is detected
  - Documentation updates
  * docs: Fix type of .chezmoi.kernel and .chezmoi.osRelease variables
  * docs: Update docs on auto applying changes on edit in VIM
  * docs: Document config vars for command-specific flags
  * docs: Cross link "See REF" in config variables doc
* Mon Feb 12 2024 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.46.1:
  - Features
  * feat: Add update.apply configuration variable
  * feat: Set CHEZMOI_SOURCE_FILE env var for scripts
  - Fixes
  * fix: Fix age/rage check in doctor command
* Fri Jan 26 2024 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.46.0:
  - Features
  * feat: Support rage as an alternative age encryption command
  * feat: Add re-add --recursive flag and make it the default
  * feat: Promote hooks to stable
  * feat: Promote HCP Vault Secrets template functions to stable
  * feat: Promote Doppler template functions to stable
  * feat: Promote edit --watch to stable
  - Fixes
  * fix: Defer lookup of git in $PATH for git-repo externals
  * fix: Change init to default to --config if --config-path is absent
  * fix: Handle more keepassxc-cli errors
  * fix: Reduce injection of terminal control characters into keepassxc-cli output
  - Documentation updates
  * docs: combine testing and debugging templates
  * docs: Fix names of age recipients files config variables
* Mon Jan 15 2024 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.45.0:
  - Features
  * feat: Scan for secrets with gitleaks when adding files
  * feat: Add add.encrypt configuration variable
  - Fixes
  * fix: Improve robustness of keepassxc-cli integration in open mode
  * fix: Handle keepassxc-cli localization
  * fix: Restore user args to keepassxc-cli in cache password mode
  * fix: Always use forward slashes to separate Windows paths
* Thu Jan 11 2024 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.44.0:
  - Features
  * feat: Add support for YubiKeys with KeePassXC
  - Documentation updates
  * docs: Add explanation of status characters
* Mon Jan  8 2024 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.43.0:
  - Features
  * feat: Extend rbw and rbwFields template funcs to take extra args
  * feat: Extend remove_ attribute to directories
  - Fixes
  * fix: Only invoke diff pager if there is diff output
  * fix: Handle implicit directories in externals
  * fix: add missing command annotations
  * fix: Make execute-template --init not read .chezmoitemplates
  * fix: key.txt is not written to home, but home/.config
  - Documentation updates
  * docs: Add upcoming changes to release history
  * docs: Add link to article
  * docs: Add links to articles
  * docs: Fix guide on clearing state of run_onchange_ scripts
* Mon Dec 18 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.42.3:
  - Features
  * feat: Remove nested subshell check
  * feat: Make mackupApplicationsDir func agnostic to mackup's installation method
* Tue Dec  5 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.42.2:
  - Features
  * feat: Add CHEZMOI_COMMAND_DIR env var for hooks
  - Fixes
  * fix: Fix fromJson template function deserializing non-objects
  * fix: Handle extra slashes in path arguments
* Wed Nov 29 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.42.1:
  - Fixes
  * fix: Set env vars from config file when re-reading config
  - Documentation updates
  * docs: Clarify prefix order for regular files
* Wed Nov 29 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.42.0:
  - Features
  * feat: Preserve numeric types when reading from .chezmoidata JSON and JSONC files
  * feat: Preserve integer values in fromJson and fromJsonc template funcs
  * feat: Add read-source-state hook
  - Documentation updates
  * docs: Add admonitions linking remove and forget
  * docs: Add links to blog posts
* Tue Nov 14 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.41.0:
  - Features
  * feat: Add git-commit-message to generate command
  * feat: Make commit message templates regular templates
  * feat: Add git.commitMessageTemplateFile config variable
  * feat: Add edit-config-template command
  - Fixes
  * fix: Don't escape HTML characters in JSON strings
  - Documentation updates
  * docs: Document support for the passage password manager
  * docs: add how-to for gpg ↔ age migration
  * docs: Fix default value of persistentState variable
  - Other
  * refactor: Allow mkdocs build from any origin
* Mon Oct 30 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.40.4:
  * fix: Make stdinIsATTY return false if --no-tty is passed
* Fri Oct 13 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.40.3:
  * feat: Add env config var as an alternative to scriptEnv
  * feat: Warn when overriding CHEZMOI_ env vars
  * feat: Set CHEZMOI_ and scriptEnv env vars for all invoked commands
* Wed Oct 11 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.40.2:
  * upstream version bump
- Update to version 2.40.1:
  * feat: Add Path Separator and Path List Separator to provided template values.
  * feat: Ignore AppleDouble files in externals
  * feat: find[One]Executable in user-supplied paths
  * fix: Only invoke diff pager if command modifies filesystem
  * fix: Don't use replace-executable for WinGet installations
  * fix: Add chattr +remove support for files
* Tue Sep 19 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.40.0:
  * feat: Implement the path-style flag for status
  * feat: Add plugin support
  * feat: Allow overlapping, non-conflicting externals
  * feat: Add decryption of non-armored files to age command
  * fix: Use diff pager for all diff output if configured
  * fix: provide a consistent error for cd to file
* Wed Sep  6 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.39.1:
  * fix: Ensure default template data when reading .chezmoidata in subdir
* Tue Sep  5 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.39.0:
  * feat: add .chezmoi.targetFile template variable
  * feat: Add age command
  * feat: Add bitwardenSecrets template function
  * fix: Handle .chezmoidata files in subdirectories when template has already been executed
* Mon Aug 28 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.38.0:
  * feat: Add gitHubReleases and gitHubTags
  * chore: Reformat long lines
  * feat: Add promptChoice and promptChoiceOnce template functions
  * fix: Fix minor issues with promptBool docs and errors
  * feat: Restore --autotemplate flag to add command
  * fix: Fix race condition in concurrent parsing of externals
  * chore: Update dependencies
* Mon Aug  7 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.37.0:
  * feat: Read personal mackup config files
  * feat: Add support for Doppler
  * feat: Extend re-add command to accept an optional list of targets
  * fix: Avoid concurrent map access when evaluating multiple templates
  * feat: Add isExecutable template function
  * chore: Fix isExecutable tests on Windows
  * chore: Update dependencies
* Tue Aug  1 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.36.1:
  * fix: Make detection of mackup config dir more robust
  * fix: Ensure that templates cannot modify each other's data
  * chore: Move core packages back to internal
* Tue Aug  1 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.36.0:
  * feat: Add .chezmoiexternals directory for multiple externals
  * fix: Respect setting diff.pager to the empty string as disabling the pager
  * feat: Add undocumented mackup command
  * chore: Update dependencies
* Mon Jul 17 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.35.0:
  * feat: Add archive-file externals
  * fix: Never consider localhost.localdomain in /etc/hosts as the FQDN
  * feat: Add support for HCP Vault Secrets
  * chore: Miscellaneous fixes
* Tue Jul  4 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.34.3:
  * fix: Check .chezmoiignore before protected paths
  * fix: Parse hostnames from all loopback addresses in /etc/hosts
  * fix: Respect persistentState config variable
  * chore: Miscellaneous fixes
  * chore: Update dependencies
* Mon Jun 19 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.34.2:
  * chore: Simplify code by using strings.EqualFold, time.Before
  * chore: Use http.NoBody instead of nil
  * fix: Handle multiple files in .chezmoidata directory
  * chore: Update dependencies
* Mon Jun 12 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.34.1:
  * feat: Add git.commitMessageTemplate configuration variable
* Mon Jun  5 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.34.0:
  * feat: Add support for .chezmoidata directory
  * fix: Fix init --debug flag
  * fix: Fix parsing of flags to secret keyring delete command
  * chore: Update dependencies
* Tue May 16 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.33.6:
  * fix: Only create empty files if they have the empty_ attribute
  * chore: Refactor internal handling of remove_ directories
  * chore(editorconfig): Remove quotes from editorconfig file
  * fix: Set CHEZMOI_SOURCE_DIR env var in init when using .chezmoiroot
  * chore: Update dependencies
* Fri May 12 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.33.5:
  * fix: Fix commands for managed files in exact_ directories
  * fix: Ensure the sourceDir is updated before creating config file
  * chore: Update dependencies
* Tue May  2 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.33.4:
  * fix: Fix init --promptBool for promptBoolOnce template function
  * fix: Respect executable file modes in external_ directories
  * fix: Fix chezmoi rm with files in exact_ directories
  * chore: Update dependencies
* Wed Apr 26 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.33.3:
  * fix: Correct capitalization of .chezmoi.config template variables
* Fri Apr 21 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.33.2:
  * fix: Set CHEZMOI_ environment variables for modify_ scripts
  * fix: Don't download ignored git-repo externals
  * feat: Add .chezmoi.config template variable
  * chore: Update dependencies
* Wed Apr 12 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.33.1:
  * chore: Add rbw version check to doctor command
  * fix: Allow source dir to be a git worktree
  * chore: Update dependencies
* Fri Mar 24 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.33.0:
  * fix: Don't list entries in git-repo externals as unmanaged
  * chore: Minor fixes
  * feat: Add support for ejson
  * chore: Tidy up ejson default key dir
  * feat: Add jq template function
  * chore: Deprecate --autotemplate
  * feat: Set $CHEZMOI_VERBOSE based on --verbose
  * fix: Only set $CHEZMOI_VERBOSE when --verbose is set
  * Update dependencies
* Mon Mar 13 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.32.0:
  * fix: Allow underscores and dots in GitHub dotfile repo name guesses
  * Improve chezmoi cd command
  * feat: Add support for the JSONC format
  * feat: Refuse to add chezmoi files to chezmoi
  * feat: Add pre- and post-command hooks
  * chore: Miscellaneous password manager cleanups
  * feat: Add rbw template function for Bitwarden
  * chore: Update dependencies
* Thu Mar  2 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.31.1:
  * feat: Add Dashlane password manager support
  * feat: Add Dashlane secure notes support
  * chore: Update dependencies
* Fri Feb 17 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.31.0:
  * feat: Print a warning when chezmoi add is called with an ignored entry
  * feat: Cache GitHub API results by default to stay under rate limit
  * feat: Display progress bars by default when stdout is a TTY
  * feat(bitwarden): Grab attachment by object name
  * fix: Eliminate [DEFAULT] section for fromIni map
  * feat: Add --with-stdin flag to execute-template command
  * chore: Update dependencies
* Mon Feb 13 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.30.1:
  * Add deleteValueAtPath and pruneEmptyDicts template functions
  * feat: Extend toPrettyJson template function to take indent
  * fix: Fix chezmoi target-path when using .chezmoiroot
  * chore: Use strings.Cut{Prefix,Suffix}
* Tue Feb  7 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.30.0:
  * feat: Add zstd compression support
  * feat: Add external_ attribute for directories
  * fix: Make chezmoi init --purge-binary always remove binary
  * Set CHEZMOI* environment variables when running cd command
  * chore: Update dependencies
* Wed Jan 25 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.29.4:
  * fix: Revert buggy diff library
* Tue Jan 24 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.29.3:
  * feat: Add --recursive flag to chattr command
  * feat: Check config file format in doctor command
  * fix: Support .zip files with empty internal directories
  * fix: Only prompt once for KeePassXC password
  * fix: Remove problematic username guessing in init command
* Mon Jan 16 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Remove `changesgenerate` service
  Upstream provides a better changelog than the one this service is able to
  generate from git commits.
* Mon Jan 16 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.29.2:
  * feat: Add keepassxc.prompt config variable
  * chore: Update dependencies
* Mon Jan  9 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.29.1:
  * fix: Fix init --ssh
  * feat: Add hexDecode and hexEncode template functions
  * fix: Fix bug where edit --watch only applied the first change
  * fix: Don't request authentication when cloning public repo with builtin git
  * fix: Improve error message when state database cannot be locked
  * chore: Improve error message when persistent state cannot be opened
  * feat: Allow cd command to take the destination directory as an argument
  * feat: Add --path-style=source-{absolute,relative} option to managed command
  * feat: Allow .chezmoi{external,ignore,remove} files to have a .tmpl suffix
  * chore: Update dependencies
* Thu Dec 22 2022 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.28.0:
  * feat: Add lstat template function
  * feat: Add --path-style option to managed and unmanaged commands
  * feat: Add verification of external checksums
  * chore: Update dependencies
* Mon Dec  5 2022 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.27.3:
  * fix: Respect config file umask setting when creating entries
  * fix: Don't attempt to run empty scripts
  * chore: Update dependencies
  * docs: Update stat.md to reference os.Stat
* Fri Nov 25 2022 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.27.2:
  * fix: Respect diff filter in removes with external diff tool
  * fix: Allow underscores in SourceHut usernames
  * feat: Add update.command and update.args config variables
  * feat: Add an optional path argument to the cd command
  * chore: Check that not both of --force and --interactive flags are set
  * fix: Make re-add command respect --interactive flag
  * chore: Update dependencies
* Mon Nov 14 2022 filippo.bonazzi@suse.com
- Update to version 2.27.1:
  * chore: Make generation of versioninfo.json work without tags or git repo
  * feat: Remember HTTP username in URL in init command
  * fix: Don't show always scripts in apply --verbose when excluded from diffs
* Wed Nov  9 2022 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.27.0:
    feat: Suppress newlines from onepasswordRead
    feat: Allow modify_ scripts to be executed as templates
    chore: Blacklist buggy version of github.com/bmatcuk/doublestar/v4
    feat: Add line ending template directive
    feat: Add setValueAtPath template function
    fix: Don't merge non-files in merge-all command
    feat: Add --script-contents flag to diff command
    chore: Better handle errors when globbing
    feat: Add cat-config and dump-config commands
    chore: Remove unused field
    chore: Refactor handling of annotations
    feat: Allow prompt*Once template functions to take paths
    fix: Fix exclusion of externals
    chore: Update dependencies
    feat: Add completion template function
* Wed Nov  2 2022 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.26.0:
    feat: Improve handling of include and exclude for externals and encrypted files
    feat: Extend --include and --exclude flags to include templates
    feat: Add --recurse-submodules flag to init and update command
    chore: Fix refactored --include and --exclude flags
    feat: Add per-template configurable delimiters
    chore: Tweak template directive implementation
    feat: Add option to exclude scripts that are always run
    fix: Extend template directives functionality
    chore: Fix comments that start from an incorrect name
    chore: Use fs.ModePerm instead of 0o777 for all permissions
    fix: Include git repo external state in state dump output
    chore: Improve error messages from git-repo externals
    fix: Construct templateDataMap manually
    chore: Reorder eqFold template function reference page
    chore: Update dependencies
* Fri Oct 21 2022 Jan Engelhardt <jengelh@inai.de>
- Put up new package description following
  https://en.opensuse.org/openSUSE:Package_description_guidelines
* Thu Oct 20 2022 filippo.bonazzi@suse.com
- Update to version 2.25.0
    fix: Use textconv in interactive diffs
    feat: Add shell completion for --include and --exclude flags
    feat: Add eqFold template function
    feat: Add scriptEnv configuration variable
    feat: Use target paths in automatically generated commit messages
    feat: 1Password account lookup table
    chore: Fail if multiple config file templates or config files are found
    fix: Make chattr {no,}encrypted decrypt and encrypt source file
* Fri Sep 30 2022 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Clean up spec file
* Thu Sep 29 2022 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Initial version 2.24.0
